/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.tabs.summary;

import java.util.Map;
import java.util.Map.Entry;

import org.dussan.vaadin.dtabs.demo.ui.tree.TabsTree;

import com.vaadin.event.MouseEvents.ClickEvent;
import com.vaadin.event.MouseEvents.ClickListener;
import com.vaadin.server.Page;
import com.vaadin.server.ThemeResource;
import com.vaadin.shared.ui.label.ContentMode;
import com.vaadin.ui.CssLayout;
import com.vaadin.ui.Embedded;
import com.vaadin.ui.Label;
import com.vaadin.ui.VerticalLayout;

public class TabsSummary
    extends VerticalLayout
{

    private static final long serialVersionUID = 3820400646479836281L;

    private boolean isAttached = false;

    private Map<String, Map<String, String[]>> tabs = null;

    public TabsSummary( Map<String, Map<String, String[]>> tabs )
    {
        this.tabs = tabs;
    }

    private void init()
    {
        setSizeUndefined();
        setWidth( 100, Unit.PERCENTAGE );

        for ( Entry<String, Map<String, String[]>> tab : tabs.entrySet() )
        {
            String tabType = tab.getKey();
            Map<String, String[]> tempTabs = tab.getValue();

            VerticalLayout tabsLayout = new VerticalLayout();
            tabsLayout.setSizeUndefined();
            tabsLayout.setWidth( 100, Unit.PERCENTAGE );
            tabsLayout.setStyleName( "tabsLayout" );
            addComponent( tabsLayout );

            Label tabTypeLabel = new Label();
            tabTypeLabel.setWidth( 100, Unit.PERCENTAGE );
            tabTypeLabel.setStyleName( "tabTypeLabel" );
            tabsLayout.addComponent( tabTypeLabel );

            CssLayout cssLayout = new CssLayout();
            cssLayout.setSizeUndefined();
            cssLayout.setWidth( 100, Unit.PERCENTAGE );
            tabsLayout.addComponent( cssLayout );

            for ( Entry<String, String[]> tempTab : tempTabs.entrySet() )
            {
                String tabName = tempTab.getKey();
                String tabDescription = tempTab.getValue()[0];
                String tabLongDescription = tempTab.getValue()[1];
                if ( tabType.equals( tabName ) )
                {
                    tabTypeLabel.setValue( tabDescription );
                }
                else
                {
                    VerticalLayout tabLayout = new VerticalLayout();
                    tabLayout.setSizeUndefined();
                    tabLayout.setStyleName( "tabLayout" );
                    cssLayout.addComponent( tabLayout );

                    Embedded tabImage =
                        new Embedded( null, new ThemeResource( "images/" + tabType + "/" + tabName + ".png" ) );
                    tabImage.setStyleName( "tabImage" );
                    tabImage.setId( tabType + "/" + tabName );
                    tabLayout.addComponent( tabImage );

                    Label tabLabel = new Label( tabLongDescription );
                    tabLabel.setStyleName( "tabLabel" );
                    if ( TabsTree.isNewTab( tabType, tabName ) )
                    {
                        tabLabel.setContentMode( ContentMode.HTML );
                        tabLabel.setValue( "<span class='new-tab'>" + tabLongDescription + "</span>" );
                    }
                    tabLayout.addComponent( tabLabel );
                    tabImage.addClickListener( new ClickListener()
                    {
                        private static final long serialVersionUID = 301424711026984913L;

                        @Override
                        public void click( ClickEvent event )
                        {
                            String fragment = event.getComponent()
                                                   .getId();
                            Page.getCurrent()
                                .setUriFragment( fragment );
                        }
                    } );
                }
            }
        }
    }

    @Override
    public void attach()
    {
        if ( !isAttached )
        {
            isAttached = true;
            super.attach();
            init();
        }
    }

    @Override
    public void detach()
    {
        if ( isAttached )
        {
            isAttached = false;
            super.detach();
        }
    }

}
